@@ -38,24 +38,6 @@
   #define S_ISLNK(mode) (0)
 #endif
 
-/* Implementation of strnlen for portability */
-static size_t spvm_strnlen(const char *s, size_t maxlen) {
-  const char *p = s;
-  
-  /* Find the null terminator or reach maxlen */
-  while (maxlen > 0 && *p != '\0') {
-    p++;
-    maxlen--;
-  }
-  
-  /* Return the number of characters before the terminator */
-  return (size_t)(p - s);
-}
-
-/* Use the portable implementation */
-#undef strnlen
-#define strnlen spvm_strnlen
-
 /*
  * Copy src to string dst of size siz.  At most siz-1 characters
  * will be copied.  Always NUL terminates (unless siz == 0).
@@ -847,7 +829,7 @@ glob3(Char *pathbuf, Char *pathbuf_last, Char *pathend, Char *pathend_last,
  *
  * Invariant of the glob_t structure:
  *	Either gl_pathc is zero and gl_pathv is NULL; or gl_pathc > 0 and
- *	gl_pathv points to (gl_offs + gl_pathc + 1) args_width.
+ *	gl_pathv points to (gl_offs + gl_pathc + 1) items.
  */
 static int
 globextend(const Char *path, glob_t *pglob, struct glob_lim *limitp,
@@ -884,7 +866,7 @@ globextend(const Char *path, glob_t *pglob, struct glob_lim *limitp,
 	if (pathv == NULL)
 		goto nospace;
 	if (pglob->gl_pathv == NULL && pglob->gl_offs > 0) {
-		/* first time around -- clear initial gl_offs args_width */
+		/* first time around -- clear initial gl_offs items */
 		pathv += pglob->gl_offs;
 		for (i = pglob->gl_offs; i > 0; i--)
 			*--pathv = NULL;
@@ -896,7 +878,7 @@ globextend(const Char *path, glob_t *pglob, struct glob_lim *limitp,
 		if (statv == NULL)
 			goto nospace;
 		if (pglob->gl_statv == NULL && pglob->gl_offs > 0) {
-			/* first time around -- clear initial gl_offs args_width */
+			/* first time around -- clear initial gl_offs items */
 			statv += pglob->gl_offs;
 			for (i = pglob->gl_offs; i > 0; i--)
 				*--statv = NULL;
